<?php

class CartDetails
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    // Method to add an item to the cart
 

    // Method to fetch cart items for a specific IP address
    function getCartItemCount($pdo, $user_id) {
        try {
            $stmt = $pdo->prepare("SELECT COUNT(*) FROM cart_details WHERE user_id = :user_id");
            $stmt->execute([':user_id' => $user_id]);
            return $stmt->fetchColumn(); // Fetch the count from the first column
        } catch (Exception $e) {
            // Handle any errors
            return 0;
        }
    }

    function getCartDetails($pdo, $user_id) {
            try {
                $stmt = $pdo->prepare("SELECT p.product_name, p.product_image, p.product_price, cd.quantity, cd.product_id
                                       FROM cart_details cd 
                                       JOIN products p ON cd.product_id = p.product_id 
                                       WHERE cd.user_id = :user_id");
                $stmt->execute([':user_id' => $user_id]);
                return $stmt->fetchAll(PDO::FETCH_ASSOC);
            } catch (Exception $e) {
                // Handle any errors
                return [];
            }
        }

    // Method to delete an item from the cart
    public function deleteItem($ipAddress, $productId)
    {
        try {
            $stmt = $this->pdo->prepare("DELETE FROM cart_details WHERE ip_address = :ip_address AND product_id = :product_id");
            $stmt->execute([':ip_address' => $ipAddress, ':product_id' => $productId]);
            return $stmt->rowCount();
        } catch (PDOException $e) {
            return false;
        }
    }

    // Method to update the quantity of an item in the cart
    public function updateQuantity($user_id, $productId, $quantity)
    {
        try {
            $stmt = $this->pdo->prepare("UPDATE cart_details SET quantity = :quantity WHERE user_id = :user_id AND product_id = :product_id");
            $stmt->execute([':quantity' => $quantity, ':user_id' => $user_id, ':product_id' => $productId]);
            return $stmt->rowCount();
        } catch (PDOException $e) {
            return false;
        }
    }

    // Method to clear all items from the cart for a specific IP address
    public function clearCart($user_id)
    {
        try {
            $stmt = $this->pdo->prepare("DELETE FROM cart_details WHERE user_id = :user_id");
            $stmt->execute(['$user_id' => $user_id]);
            return $stmt->rowCount();
        } catch (PDOException $e) {
            return false;
        }
    }
}
?>
