<?php 
session_start(); // Start the session 
include('header.php');

require('../superadmin/model/Products.php'); 
require('model/CartDetails.php');


// Check if dealer_id is set in the session
if (isset($_SESSION['dealer_id'])) {
    $user_id = $_SESSION['dealer_id']; // Get the user_id from the session
} else {
    $user_id = null; // Handle the case when dealer_id is not set
}

$msg_alert = '';

$products = new Products($pdo);
$allProducts = $products->fetchAllProducts(); 

$cart = new CartDetails($pdo);

function getIPAddress() {  
    if (!empty($_SERVER['HTTP_CLIENT_IP'])) {  
        $ip = $_SERVER['HTTP_CLIENT_IP'];  
    } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {  
        $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];  
    } else {  
        $ip = $_SERVER['REMOTE_ADDR'];  
    }  
    return $ip;  
}

if (isset($_POST['add_to_cart'])) {
    $get_product_id = $_POST['product_id'];
    $quantity = $_POST['quantity'];
    $ip = getIPAddress();

    // Ensure the user is logged in
    if (!$user_id) {
        $msg_alert = '<div class="alert alert-danger" role="alert"><strong>Error - </strong> Please log in to add items to the cart. <a class="btn btn-success" href="signin.php"> Login </a> </div>';
    } else {
        // Check if the item is already in the cart
        $stmt = $pdo->prepare("SELECT quantity FROM cart_details WHERE user_id = :user_id AND product_id = :product_id");
        $stmt->execute([':user_id' => $user_id, ':product_id' => $get_product_id]);
        $existingQuantity = $stmt->fetchColumn();

        if ($existingQuantity !== false) {
            // Item exists, update quantity
            $newQuantity = $existingQuantity + $quantity;
            $stmt = $pdo->prepare("UPDATE cart_details SET quantity = :quantity WHERE user_id = :user_id AND product_id = :product_id");
            $stmt->execute([':quantity' => $newQuantity, ':user_id' => $user_id, ':product_id' => $get_product_id]);
        } else {
            // Item does not exist, insert new
            $stmt = $pdo->prepare("INSERT INTO cart_details (user_id, product_id, quantity) VALUES (:user_id, :product_id, :quantity)");
            $stmt->execute([':user_id' => $user_id, ':product_id' => $get_product_id, ':quantity' => $quantity]);
        }

        if ($stmt) {
            $msg_alert = '<div class="alert alert-success" role="alert"><strong>Success - </strong> Product added to cart!</div>';
        } else {
            $msg_alert = '<div class="alert alert-danger" role="alert"><strong>Error - </strong> Something went wrong.</div>';
        }
    }
}

$ip = getIPAddress(); 
$cartItemCount = $cart->getCartItemCount($pdo, $user_id); 
$cartDetails = $cart->getCartDetails($pdo, $user_id); 

?>



<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">



<style>
.heading {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
    font-size: 1.2em;
    margin-top: 5px;
    margin-left: 10px;               
    font-weight: 600;
}

.description {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    width: 80%;
    margin-left: 10px;             
}

.price {
    text-align: center;
    width: 120px;
    height: auto;
    margin-left: 10px;       
    margin-top: 5px;
    padding: 2px;
    color: #02ad35;
    border: 1px solid #02ad35;
    border-radius: 20px;
}
</style>

<section class="pcoded-main-container">
    <div class="pcoded-content">
        <div class="page-header">
            <div class="page-block">
                <div class="row align-items-center">
                    <div class="col-md-12"> 
                        <div class="page-header-title">
                            <h5 class="m-b-10">Location</h5>
                        </div>
                        <ul class="breadcrumb">
                            <li class="breadcrumb-item"><a href="index"><i class="feather icon-home"></i></a></li>
                            <li class="breadcrumb-item"><a href="#!">Company Orders</a></li>
                            <li class="breadcrumb-item"><a href="place-new-order">Place New Order</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>

        <div class="page-header">
            <?php if ($msg_alert != ""): ?>
                <?php echo $msg_alert; ?>
            <?php endif; ?>
            <div class="page-block">
                <div class="row align-items-center">
                    <div class="col-md-12"> 
                        <div class="page-header-title">
                            <h1 class="m-b-10">Place New Order <i class="fas fa-shopping-cart" data-toggle="modal" data-target="#shoppingModal" style="cursor: pointer;">
                                 <sup class="text-primary"> <?php echo htmlspecialchars($cartItemCount); ?>  </sup> </i> </h1>
                        </div>
                        <div class="row">
                            <div class="col-md-12">         
                                <ul class="nav nav-pills mb-3" id="pills-tab" role="tablist">
                                    <li class="nav-item" role="presentation">
                                        <button class="nav-link active" id="pills-home-tab" data-bs-toggle="pill" data-bs-target="#pills-home" type="button" role="tab" aria-controls="pills-home" aria-selected="true" style="border:none;margin:5px;">Home</button>
                                    </li>
                                    <li class="nav-item" role="presentation">
                                        <button class="nav-link" id="pills-profile-tab" data-bs-toggle="pill" data-bs-target="#pills-profile" type="button" role="tab" aria-controls="pills-profile" aria-selected="false" style="border:none;margin:5px;">Profile</button>
                                    </li>
                                    <li class="nav-item" role="presentation">
                                        <button class="nav-link" id="pills-contact-tab" data-bs-toggle="pill" data-bs-target="#pills-contact" type="button" role="tab" aria-controls="pills-contact" aria-selected="false" style="border:none;margin:5px;">Contact</button>
                                    </li>
                                </ul>
                            </div>
                            <div class="col-md-12" style="padding:0px;">         
                                <div class="tab-content" id="pills-tabContent">
                                    <div class="tab-pane fade show active" id="pills-home" role="tabpanel" aria-labelledby="pills-home-tab">
                                        <div class="row py-3 align-items-center">
                                            <?php foreach ($allProducts as $product): ?>
                                                <div class="col-md-3 mb-3">
                                                    <form method="POST">
                                                       <div class="card">
                                                                <img class="card-img-top img-fluid" src="../superadmin/products/<?php echo htmlspecialchars($product['product_image']); ?>" alt="Product Image" style="height: 200px; object-fit: cover;">
                                                                <div class="card-body">
                                                                    <h5 class="card-title"><?php echo htmlspecialchars($product['product_name']); ?></h5>
                                                                    <p class="card-text"><?php echo htmlspecialchars($product['product_description']); ?></p>
                                                                    <p class="card-text"><strong>Price: ₹ <?php echo htmlspecialchars($product['product_price']); ?></strong></p>
                                                                    <div class="form-group" style="margin-top:6px;">
                                                                        <label style="display:flex;">Quantity:</label>
                                                                        <div class="d-flex">
                                                                            <button type="button" class="btn btn-link px-2" onclick="this.parentNode.querySelector('input[type=number]').stepDown()">
                                                                                <i class="fas fa-minus"></i>
                                                                            </button>
                                                                            <input min="1" name="quantity" value="1" type="number" class="form-control form-control-sm" style="width:50px;" />
                                                                            <button type="button" class="btn btn-link px-2" onclick="this.parentNode.querySelector('input[type=number]').stepUp()">
                                                                                <i class="fas fa-plus"></i>
                                                                            </button>
                                                                        </div>
                                                                    </div>
                                                                    <input type="hidden" name="product_id" value="<?php echo htmlspecialchars($product['product_id']); ?>">
                                                                    <button name="add_to_cart" class="btn btn-primary" type="submit" style="width:100%;background:black;border:none;">Add to Cart</button>
                                                                </div>
                                                            </div>

                                                    </form>
                                                </div>
                                            <?php endforeach; ?>
                                        </div>

 <!-- Modal Code -->
<div class="modal fade" id="shoppingModal" tabindex="-1" aria-labelledby="shoppingModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-fullscreen">
        <div class="modal-content">
            <h6><?php echo $_SESSION['dealer_id']  . '<br>' . $_SESSION['dealer_email'] . '<br>' .  $_SESSION['username']; ?><h6>
                
            <div class="modal-header">
                <h5 class="modal-title" id="shoppingModalLabel">Shopping Cart</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <div class="container">
                    <div id="cart-container">
                        <?php if ($cartItemCount > 0): ?>
                            <?php 
                            $totalPrice = 0; // Initialize total price
                            foreach ($cartDetails as $item): 
                                $itemTotalPrice = $item['product_price'] * $item['quantity']; // Calculate total for this item
                                $totalPrice += $itemTotalPrice; // Add to total price
                            ?>
                                <div class="row mb-4 cart-item" data-product-id="<?php echo htmlspecialchars($item['product_id']); ?>">
                                    <div class="col-md-2 col-lg-2 col-xl-2">
                                        <img src="../superadmin/products/<?php echo htmlspecialchars($item['product_image']); ?>" 
                                             class="img-fluid rounded-3" 
                                             alt="<?php echo htmlspecialchars($item['product_name']); ?>">
                                    </div>
                                    <div class="col-md-3 col-lg-3 col-xl-3">
                                        <h6 class="text-muted"><?php echo htmlspecialchars($item['product_name']); ?></h6>
                                        <div class="d-flex align-items-center">
                                            <button type="button" class="btn btn-link px-2 decrement-btn" data-product-id="<?php echo htmlspecialchars($item['product_id']); ?>">
                                                <i class="fas fa-minus"></i>
                                            </button>
                                            <input type="number" class="form-control quantity-input" value="<?php echo htmlspecialchars($item['quantity']); ?>" min="1" data-product-price="<?php echo htmlspecialchars($item['product_price']); ?>" style="width:50px;">
                                            <button type="button" class="btn btn-link px-2 increment-btn" data-product-id="<?php echo htmlspecialchars($item['product_id']); ?>">
                                                <i class="fas fa-plus"></i>
                                            </button>
                                        </div>
                                    </div>
                                    <div class="col-md-3 col-lg-3 col-xl-3">
                                        <label>Price: ₹ <?php echo htmlspecialchars($item['product_price']); ?></label>
                                    </div>
                                    <div class="col-md-4 col-lg-4 col-xl-4 d-flex align-items-center">
                                        <div class="d-flex flex-column w-100">
                                            <h6 class="text-muted">Total Price</h6>
                                            <h6 class="item-total-price">₹ <?php echo htmlspecialchars($itemTotalPrice); ?></h6>
                                            <button type="button" class="btn btn-danger btn-sm remove-btn" data-product-id="<?php echo htmlspecialchars($item['product_id']); ?>">Remove</button>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-12 border-top border-secondary"></div>
                                </div>
                            <?php endforeach; ?>
                            <div class="row">
                                <div class="col-md-12">
                                    <h5>Total Amount: ₹ <span id="totalAmount"><?php echo htmlspecialchars($totalPrice); ?></span></h5>
                                </div>
                            </div>
                        <?php else: ?>
                            <div class="row">
                                <div class="col-12">
                                    <h6 class="text-muted">Your cart is empty.</h6>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancel</button>
                <button type="button" class="btn btn-danger placeOrder">Place Order</button>
            </div>
        </div>
    </div>
</div>


<script src="assets/js/vendor-all.min.js"></script>
<script src="assets/js/plugins/bootstrap.min.js"></script>
<script src="assets/js/pcoded.min.js"></script>

 
  
<script>
    // Update Cart UI
    function updateCartUI(product_id, newQuantity, newItemTotalPrice, newTotalAmount) {
        var $cartItem = $('.cart-item[data-product-id="' + product_id + '"]');
        $cartItem.find('.quantity-input').val(newQuantity);
        $cartItem.find('.item-total-price').text('₹ ' + newItemTotalPrice);
        $('#totalAmount').text(newTotalAmount);
    }

    // Remove Cart Item UI
    function removeCartItemUI(product_id, newTotalAmount) {
        $('.cart-item[data-product-id="' + product_id + '"]').remove();
        $('#totalAmount').text(newTotalAmount);
    }

    // Increase quantity
    $(document).on('click', '.increment-btn', function() {
        var product_id = $(this).data('product-id');
        $.post('update_cart_quantity.php', { product_id: product_id, action: 'increment' }, function(response) {
            var data = $.parseJSON(response);
            if (data.status === 'success') {
                updateCartUI(product_id, data.newQuantity, data.newItemTotalPrice, data.newTotalAmount);
            } else {
                alert('Could not update quantity. Please try again.');
            }
        });
    });

    // Decrease quantity
    $(document).on('click', '.decrement-btn', function() {
        var product_id = $(this).data('product-id');
        $.post('update_cart_quantity.php', { product_id: product_id, action: 'decrement' }, function(response) {
            var data = $.parseJSON(response);
            if (data.status === 'success') {
                if (data.newQuantity === 0) {
                    removeCartItemUI(product_id, data.newTotalAmount);
                } else {
                    updateCartUI(product_id, data.newQuantity, data.newItemTotalPrice, data.newTotalAmount);
                }
            } else {
                alert('Could not update quantity. Please try again.');
            }
        });
    });

    // Remove item
    $(document).on('click', '.remove-btn', function() {
        var product_id = $(this).data('product-id');
        $.post('remove_cart_item.php', { product_id: product_id }, function(response) {
            var data = $.parseJSON(response);
            if (data.status === 'success') {
                removeCartItemUI(product_id, data.newTotalAmount);
            } else {
                alert('Could not remove item. Please try again.');
            }
        });
    });

    // Place Order
    $(document).on('click', '.placeOrder', function() {
        $.post('place_order.php', function(response) {
            try {
                var data = $.parseJSON(response); // Parse JSON
                if (data.status === 'success') {
                    alert('Order placed successfully!');
                    $('#shoppingModal').modal('hide');
                    window.location.href = 'orders.php';
                } else {
                    alert('Something went wrong: ' + data.message);
                }
            } catch (e) {
                console.error('Failed to parse JSON response:', response);
                alert('Failed to process the order. Please try again.');
            }
        });
    });



</script> 

