<?php
session_start();
include('header.php');
require('../superadmin/model/Products.php');

$products = new Products($pdo);
$allProducts = $products->fetchAllProducts();
$msg_alert = '';

// Initialize cart session
if (!isset($_SESSION['cart'])) {
    $_SESSION['cart'] = [];
}

if (isset($_POST['addToCart'])) {
    $product_id = $_POST['product_id'];
    $quantity = 1; // Default quantity

    // Fetch product by ID
    $product = $products->fetchProductById($product_id);

    if ($product) {
        // Add product to cart session
        if (isset($_SESSION['cart'][$product_id])) {
            $_SESSION['cart'][$product_id]['quantity'] += $quantity;
        } else {
            $_SESSION['cart'][$product_id] = [
                'product_id' => $product['product_id'],
                'product_name' => $product['product_name'],
                'product_price' => $product['product_price'],
                'quantity' => $quantity
            ];
        }
        $msg_alert = '<div class="alert alert-success" role="alert"><strong>Success - </strong>Product added to cart!</div>';
    } else {
        $msg_alert = '<div class="alert alert-danger" role="alert"><strong>Error - </strong>Product not found!</div>';
    }
}
?>

<!-- [ Main Content ] start -->
<section class="pcoded-main-container">
    <div class="pcoded-content">
        <!-- [ breadcrumb ] start -->
        <div class="page-header">
            <div class="page-block">
                <div class="row align-items-center">
                    <div class="col-md-12">
                        <div class="page-header-title">
                            <h5 class="m-b-10">Location</h5>
                        </div>
                        <ul class="breadcrumb">
                            <li class="breadcrumb-item"><a href="index"><i class="feather icon-home"></i></a></li>
                            <li class="breadcrumb-item"><a href="#!">Company Orders</a></li>
                            <li class="breadcrumb-item"><a href="place-new-order">Place New Order</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
        <!-- [ breadcrumb ] end -->
        <!-- [ Main Content ] start -->
        <div class="row">
            <!-- [ form-element ] start -->
            <div class="col-sm-12">
                <form method="post">
                    <div class="card">
                        <div class="card-header">
                            <h3>Place New Order</h3>
                        </div>
                        <div class="card-body">
                            <?php if($msg_alert != ""): ?>
                                <?php echo $msg_alert; ?>
                            <?php endif; ?>
                            <hr>
                            <div class="row">
                                <?php if ($allProducts): ?>
                                    <?php foreach ($allProducts as $product): ?>
                                        <div class="col-md-4">
                                            <div class="card mb-4 shadow-sm">
                                                <img class="card-img-top" src="../superadmin/products/<?php echo htmlspecialchars($product['product_image']); ?>" alt="Product Image" style="max-height: 200px;">
                                                <div class="card-body">
                                                    <h5 class="card-title">Product Name : <?php echo htmlspecialchars($product['product_name']); ?></h5>
                                                    <p class="card-text">Product Description : <?php echo htmlspecialchars($product['product_description']); ?></p>
                                                    <div class="d-flex justify-content-between align-items-center">
                                                        <div class="btn-group">
                                                            <form method="post" style="display:inline;">
                                                                <input type="hidden" name="product_id" value="<?php echo $product['product_id']; ?>">
                                                                <button type="submit" name="addToCart" class="btn btn-sm btn-outline-secondary">Add to Cart</button>
                                                            </form>
                                                        </div>
                                                        <small class="text-muted">Product Price : <?php echo htmlspecialchars($product['product_price']); ?></small>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <div class="col-12">
                                        <div class="alert alert-warning text-center" role="alert">No products found.</div>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                        <div class="card-footer text-right">
                            <a href="checkout.php" class="btn btn-success">Checkout</a>
                        </div>
                    </div>
                </form>
            </div>
            <!-- [ form-element ] end -->
        </div>
        <!-- [ Main Content ] end -->
    </div>
</section>
<!-- [ Main Content ] end -->

<?php include('footer.php'); ?>














































