<?php
session_start(); // Start the session
include('config.php');

$msg_alert = "";

if (isset($_POST['signinBtn'])) {
    $email = isset($_POST['email']) ? htmlspecialchars($_POST['email']) : '';
    $password = isset($_POST['password']) ? htmlspecialchars($_POST['password']) : '';

    if (empty($email) || empty($password)) {
        $msg_alert = '<div class="alert alert-danger" role="alert"><strong>Error - </strong> All fields must be filled out!</div>';
    } else {
        $password = filter_var($password, FILTER_SANITIZE_STRING);

        $loginUser = $pdo->prepare('SELECT dealer_id, dealer_email, username, dealer_password FROM dealers_accounts WHERE dealer_email = :email');
        $loginUser->execute([':email' => $email]);

        if ($loginUser->rowCount() == 1) {
            $userDetails = $loginUser->fetch(PDO::FETCH_ASSOC);

            if (password_verify($password, $userDetails['dealer_password'])) {
                // Password is correct, set session
                $_SESSION['dealer_id'] = $userDetails['dealer_id']; // Store user ID in session
                $_SESSION['dealer_email'] = $userDetails['dealer_email']; // Optionally store email
                $_SESSION['username'] = $userDetails['username']; // Optionally store username

                header("Location: index"); // Redirect to the index page
                exit();
            } else {
                $msg_alert = '<div class="alert alert-danger" role="alert"><strong>Error - </strong> Invalid password!</div>';
            }
        } else {
            $msg_alert = '<div class="alert alert-danger" role="alert"><strong>Error - </strong> User not found!</div>';
        }
    }
}
?>


<!DOCTYPE html>
<html lang="en">

<head>
    <title>Loyal Infield - Signin</title>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=0, minimal-ui">
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <meta name="description" content="" />
    <meta name="keywords" content="">
    <meta name="author" content="Codedthemes" />
    <!-- Favicon icon -->
    <link rel="icon" href="assets/images/favicon.ico" type="image/x-icon">
    <!-- vendor css -->
    <link rel="stylesheet" href="assets/css/style.css">
</head>

<body>
    <!-- [ auth-signin ] start -->
    <div class="auth-wrapper">
        <div class="auth-content">
            <div class="card">
                <div class="row align-items-center text-center">
                    <div class="col-md-12">
                        <div class="card-body">
                            <form id="signinForm" method="post">
                                <img src="assets/images/logo-dark.png" alt="" class="img-fluid mb-4">
                                <h4 class="mb-3 f-w-400">Dealer Signin</h4>
                                <?php if ($msg_alert != "") {
                                    echo $msg_alert;
                                } ?>
                                <div class="input-group mb-3">
                                    <div class="input-group-prepend">
                                        <span class="input-group-text"><i class="feather icon-mail"></i></span>
                                    </div>
                                    <input type="email" id="email" name="email" class="form-control" placeholder="Email address">
                                </div>
                                <div class="input-group mb-4">
                                    <div class="input-group-prepend">
                                        <span class="input-group-text"><i class="feather icon-lock"></i></span>
                                    </div>
                                    <input type="password" id="password" name="password" class="form-control" placeholder="Password">
                                </div>
                                <p class="text-danger" id="alerts" style="display:none;"></p>
                                <div class="form-group text-left mt-2">
                                    <div class="checkbox checkbox-primary d-inline">
                                        <input type="checkbox" name="checkbox-fill-1" id="checkbox-fill-a1" checked="">
                                        <label for="checkbox-fill-a1" class="cr"> Save credentials</label>
                                    </div>
                                </div>
                                <button class="btn btn-block btn-primary mb-4" type="submit" name="signinBtn">Signin</button>
                                <p class="mb-2 text-muted">Forgot password? <a href="auth-reset-password.html" class="f-w-400">Reset</a></p>
                                <p class="mb-0 text-muted">Don’t have an account? <a href="auth-signup.html" class="f-w-400">Signup</a></p>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- [ auth-signin ] end -->

    <!-- Required Js -->
    <script src="assets/js/vendor-all.min.js"></script>
    <script src="assets/js/plugins/bootstrap.min.js"></script>
    <script src="assets/js/waves.min.js"></script>

    <script type="text/javascript">
        $(document).ready(function () {
            $("#signinForm").submit(function (event) {
                // Hide all previous error messages
                $(".text-danger").hide();

                // Retrieve input field values
                var email = $("#email").val().trim();
                var password = $("#password").val().trim();

                // Validate fields
                var isValid = true;

                if (password === "") {
                    $("#alerts").html('Please enter a password!').show();
                    isValid = false;
                }

                if (email === "") {
                    $("#alerts").html('Please enter an email address!').show();
                    isValid = false;
                }

                // Prevent form submission if any validation fails
                if (!isValid) {
                    event.preventDefault();
                }
            });
        });
    </script>
</body>

</html>
